@@ -1,5 +1,5 @@
 package Plack::Handler::Stomp;
-$Plack::Handler::Stomp::VERSION = '1.09';
+$Plack::Handler::Stomp::VERSION = '1.10';
 {
   $Plack::Handler::Stomp::DIST = 'Plack-Handler-Stomp';
 }
@@ -27,8 +27,8 @@ has logger => (
     lazy_build => 1,
 );
 sub _build_logger {
-    require Plack::Handler::Stomp::StupidLogger;
-    Plack::Handler::Stomp::StupidLogger->new();
+    require Net::Stomp::StupidLogger;
+    Net::Stomp::StupidLogger->new();
 }
 
 sub _build_connection {
@@ -355,7 +355,7 @@ Plack::Handler::Stomp - adapt STOMP to (almost) HTTP, via Plack
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -400,8 +400,8 @@ documentation to see how to configure servers and subscriptions.
 A logger object used by thes handler. Not to be confused by the logger
 used by the application (either internally, or via a Middleware). Can
 be any object that can C<debug>, C<info>, C<warn>, C<error>. Defaults
-to an instance of L<Plack::Handler::Stomp::StupidLogger>. This logger
-is passed on to the L<Net::Stomp> object held in C<connection> (see
+to an instance of L<Net::Stomp::StupidLogger>. This logger is passed
+on to the L<Net::Stomp> object held in C<connection> (see
 L<Net::Stomp::MooseHelpers::CanConnect>).
 
 =head2 C<destination_path_map>
